@@ -1,3 +1,4 @@
+from django.apps import apps
 from django.contrib.auth.decorators import login_required
 from django.forms import formset_factory
 from django.http import HttpResponse, HttpResponseRedirect
@@ -5,9 +6,9 @@ from django.shortcuts import get_object_or_404, render
 from django.template.loader import render_to_string
 from django.urls import reverse
 
-import datetime, os, sys
+import datetime, importlib, os, sys
 
-from .utils import get_params_for_search
+from .utils import generate_xlsx, get_params_for_search
 
 # Create your views here.
 
@@ -387,7 +388,9 @@ def general_obj(request, Obj, ObjForm, general_obj_id, fields=(), \
 
 def general_obj_search(request, Obj, ObjForm, search_fields=(), \
         result_fields=(), template=False, allow_prompt_ajax_search=False, \
-        relational_obj_values={}, translations={}, *args, **kwargs):
+        relational_obj_values={}, translations={}, \
+        import_instruction_for_obj=False, import_instruction_for_report=False, \
+        *args, **kwargs):
     if not template:
         template = 'generalobj_search.html'
     ret_dic = {}
@@ -400,6 +403,8 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
         ret_dic['passing_scripts'] = kwargs['passing_scripts']
     ret_dic['url_new'] = reverse('%s_new' % ret_dic['class_name'].lower())
     ret_dic['allow_prompt_ajax_search'] = allow_prompt_ajax_search
+    ret_dic['import_instruction_for_obj'] = import_instruction_for_obj
+    ret_dic['import_instruction_for_report'] = import_instruction_for_report
     return render(request, template, ret_dic)
 
 
@@ -477,5 +482,23 @@ def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
 
 
 def download_excelsheet(request):
-    print(request.POST)
-    pass
\ No newline at end of file
+    import_instruction_for_obj = \
+            request.GET.get('ge_import_instruction_for_obj', '')
+    import_instruction_for_report = \
+            request.GET.get('ge_import_instruction_for_report', '')
+    ge_ids = request.GET.get('ge_ids', '')
+
+    (_model, _cls) = import_instruction_for_obj.split('.')
+    Obj = apps.get_model(_model, _cls)
+    obj_list = locals()['Obj'].objects.filter(id__in=ge_ids.split(','))
+
+    (_modul, _file, _var, _key) = import_instruction_for_report.split('|')
+    module = importlib.import_module('%s.%s' % (_modul, _file))
+    reports = getattr(module, _var)
+    report = reports[_key]
+
+    filename = generate_xlsx(obj_list, report)
+    download = open(filename, 'rb')
+    response = HttpResponse(download.read())
+    response['Content-Disposition'] = 'attachment; filename=%s' % filename
+    return response
